@@ -39,7 +39,7 @@ typedef enum
  */
 #define ECORE_AUDIO_CLASS ecore_audio_class_get()
 
-EWAPI const Efl_Class *ecore_audio_class_get(void);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK const Efl_Class *ecore_audio_class_get(void) EINA_CONST;
 
 /**
  * @brief Pauses state of the object
@@ -49,7 +49,7 @@ EWAPI const Efl_Class *ecore_audio_class_get(void);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI void ecore_audio_obj_paused_set(Eo *obj, Eina_Bool paused);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK void ecore_audio_obj_paused_set(Eo *obj, Eina_Bool paused);
 
 /**
  * @brief Pauses state of the object
@@ -60,7 +60,7 @@ EOAPI void ecore_audio_obj_paused_set(Eo *obj, Eina_Bool paused);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI Eina_Bool ecore_audio_obj_paused_get(const Eo *obj);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK Eina_Bool ecore_audio_obj_paused_get(const Eo *obj);
 
 /**
  * @brief Volume of the object
@@ -70,7 +70,7 @@ EOAPI Eina_Bool ecore_audio_obj_paused_get(const Eo *obj);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI void ecore_audio_obj_volume_set(Eo *obj, double volume);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK void ecore_audio_obj_volume_set(Eo *obj, double volume);
 
 /**
  * @brief Volume of the object
@@ -81,7 +81,7 @@ EOAPI void ecore_audio_obj_volume_set(Eo *obj, double volume);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI double ecore_audio_obj_volume_get(const Eo *obj);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK double ecore_audio_obj_volume_get(const Eo *obj);
 
 /**
  * @brief Source of the object
@@ -97,7 +97,7 @@ EOAPI double ecore_audio_obj_volume_get(const Eo *obj);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI Eina_Bool ecore_audio_obj_source_set(Eo *obj, const char *source);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK Eina_Bool ecore_audio_obj_source_set(Eo *obj, const char *source);
 
 /**
  * @brief Source of the object
@@ -111,7 +111,7 @@ EOAPI Eina_Bool ecore_audio_obj_source_set(Eo *obj, const char *source);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI const char *ecore_audio_obj_source_get(const Eo *obj);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK const char *ecore_audio_obj_source_get(const Eo *obj);
 
 /**
  * @brief Format of the object.
@@ -128,7 +128,7 @@ EOAPI const char *ecore_audio_obj_source_get(const Eo *obj);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI Eina_Bool ecore_audio_obj_format_set(Eo *obj, Ecore_Audio_Format format);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK Eina_Bool ecore_audio_obj_format_set(Eo *obj, Ecore_Audio_Format format);
 
 /**
  * @brief Format of the object.
@@ -144,7 +144,7 @@ EOAPI Eina_Bool ecore_audio_obj_format_set(Eo *obj, Ecore_Audio_Format format);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
 
 /**
  * @brief Sets the virtual IO functions
@@ -157,7 +157,7 @@ EOAPI Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
  *
  * @ingroup Ecore_Audio
  */
-EOAPI void ecore_audio_obj_vio_set(Eo *obj, Ecore_Audio_Vio *vio, void *data, efl_key_data_free_func free_func);
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK void ecore_audio_obj_vio_set(Eo *obj, Ecore_Audio_Vio *vio, void *data, efl_key_data_free_func free_func);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
