@@ -20,7 +20,7 @@ typedef Eo Ecore_Audio_In_Sndfile;
  */
 #define ECORE_AUDIO_IN_SNDFILE_CLASS ecore_audio_in_sndfile_class_get()
 
-EWAPI const Efl_Class *ecore_audio_in_sndfile_class_get(void) EINA_CONST;
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK const Efl_Class *ecore_audio_in_sndfile_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
