@@ -20,9 +20,9 @@ typedef Eo Ecore_Audio_Out_Wasapi;
  */
 #define ECORE_AUDIO_OUT_WASAPI_CLASS ecore_audio_out_wasapi_class_get()
 
-EWAPI const Efl_Class *ecore_audio_out_wasapi_class_get(void) EINA_CONST;
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK const Efl_Class *ecore_audio_out_wasapi_class_get(void) EINA_CONST;
 
-EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_READY;
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_READY;
 
 /** Called when the output is ready for playback.
  *
@@ -30,7 +30,7 @@ EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_R
  */
 #define ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_READY (&(_ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_READY))
 
-EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_FAIL;
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_FAIL;
 
 /** Called when context fails.
  *
@@ -38,7 +38,7 @@ EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_F
  */
 #define ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_FAIL (&(_ECORE_AUDIO_OUT_WASAPI_EVENT_CONTEXT_FAIL))
 
-EWAPI extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_STOP;
+ECORE_AUDIO_API ECORE_AUDIO_API_WEAK extern const Efl_Event_Description _ECORE_AUDIO_OUT_WASAPI_EVENT_STOP;
 
 /** Called when need to stop.
  *
