@@ -58,7 +58,7 @@ typedef Eo Efl_Net_Dialer_Simple;
  */
 #define EFL_NET_DIALER_SIMPLE_CLASS efl_net_dialer_simple_class_get()
 
-EWAPI const Efl_Class *efl_net_dialer_simple_class_get(void);
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_dialer_simple_class_get(void) EINA_CONST;
 
 /**
  * @brief The class used to create @ref efl_io_buffered_stream_inner_io_get if
@@ -78,7 +78,7 @@ EWAPI const Efl_Class *efl_net_dialer_simple_class_get(void);
  *
  * @ingroup Efl_Net_Dialer_Simple
  */
-EOAPI void efl_net_dialer_simple_inner_class_set(Eo *obj, const Efl_Class *klass);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_dialer_simple_inner_class_set(Eo *obj, const Efl_Class *klass);
 
 /**
  * @brief The class used to create @ref efl_io_buffered_stream_inner_io_get if
@@ -98,7 +98,7 @@ EOAPI void efl_net_dialer_simple_inner_class_set(Eo *obj, const Efl_Class *klass
  *
  * @ingroup Efl_Net_Dialer_Simple
  */
-EOAPI const Efl_Class *efl_net_dialer_simple_inner_class_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_dialer_simple_inner_class_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
