@@ -26,7 +26,7 @@ typedef Eo Efl_Net_Dialer_Unix;
  */
 #define EFL_NET_DIALER_UNIX_CLASS efl_net_dialer_unix_class_get()
 
-EWAPI const Efl_Class *efl_net_dialer_unix_class_get(void) EINA_CONST;
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_dialer_unix_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
