@@ -29,7 +29,7 @@ typedef Eo Efl_Net_Server_Udp_Client;
  */
 #define EFL_NET_SERVER_UDP_CLIENT_CLASS efl_net_server_udp_client_class_get()
 
-EWAPI const Efl_Class *efl_net_server_udp_client_class_get(void) EINA_CONST;
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_server_udp_client_class_get(void) EINA_CONST;
 
 /**
  * @brief Query the next datagram size.
@@ -43,7 +43,7 @@ EWAPI const Efl_Class *efl_net_server_udp_client_class_get(void) EINA_CONST;
  *
  * @ingroup Efl_Net_Server_Udp_Client
  */
-EOAPI size_t efl_net_server_udp_client_next_datagram_size_query(Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK size_t efl_net_server_udp_client_next_datagram_size_query(Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
