@@ -13,13 +13,14 @@ typedef Eo Efl_Gfx_Fill;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl graphics fill interface
  *
  * @ingroup Efl_Gfx_Fill
  */
 #define EFL_GFX_FILL_INTERFACE efl_gfx_fill_interface_get()
 
-EWAPI const Efl_Class *efl_gfx_fill_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_gfx_fill_interface_get(void) EINA_CONST;
 
 /**
  * @brief Binds the object's @ref efl_gfx_fill_get property to its actual
@@ -35,12 +36,13 @@ EWAPI const Efl_Class *efl_gfx_fill_interface_get(void);
  * This flag is @c true by default (used to be @c false with the old APIs, and
  * was known as "filled").
  *
+ * @param[in] obj The object.
  * @param[in] filled @c true to make the fill property follow object size or
  * @c false otherwise.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
+EAPI EAPI_WEAK void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
 
 /**
  * @brief Binds the object's @ref efl_gfx_fill_get property to its actual
@@ -56,12 +58,14 @@ EOAPI void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
  * This flag is @c true by default (used to be @c false with the old APIs, and
  * was known as "filled").
  *
+ * @param[in] obj The object.
+ *
  * @return @c true to make the fill property follow object size or @c false
  * otherwise.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI Eina_Bool efl_gfx_fill_auto_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_gfx_fill_auto_get(const Eo *obj);
 
 /**
  * @brief Specifies how to tile an image to fill its rectangle geometry.
@@ -74,16 +78,13 @@ EOAPI Eina_Bool efl_gfx_fill_auto_get(const Eo *obj);
  *
  * Setting this property will reset the @ref efl_gfx_fill_auto_get to @c false.
  *
- * @param[in] x The x coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[in] y The y coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[in] w The width the bound image will be displayed at.
- * @param[in] h The height the bound image will be displayed at.
+ * @param[in] obj The object.
+ * @param[in] fill The top-left corner to start drawing from as well as the
+ * size at which the bound image will be displayed.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI void efl_gfx_fill_set(Eo *obj, int x, int y, int w, int h);
+EAPI EAPI_WEAK void efl_gfx_fill_set(Eo *obj, Eina_Rect fill);
 
 /**
  * @brief Specifies how to tile an image to fill its rectangle geometry.
@@ -96,15 +97,14 @@ EOAPI void efl_gfx_fill_set(Eo *obj, int x, int y, int w, int h);
  *
  * Setting this property will reset the @ref efl_gfx_fill_auto_get to @c false.
  *
- * @param[out] x The x coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[out] y The y coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[out] w The width the bound image will be displayed at.
- * @param[out] h The height the bound image will be displayed at.
+ * @param[in] obj The object.
+ *
+ * @return The top-left corner to start drawing from as well as the size at
+ * which the bound image will be displayed.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI void efl_gfx_fill_get(const Eo *obj, int *x, int *y, int *w, int *h);
+EAPI EAPI_WEAK Eina_Rect efl_gfx_fill_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
