@@ -21,7 +21,7 @@ typedef Eo Efl_Text_Markup;
  */
 #define EFL_TEXT_MARKUP_INTERFACE efl_text_markup_interface_get()
 
-EWAPI const Efl_Class *efl_text_markup_interface_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *efl_text_markup_interface_get(void) EINA_CONST;
 
 /**
  * @brief Markup property
@@ -33,7 +33,7 @@ EWAPI const Efl_Class *efl_text_markup_interface_get(void) EINA_CONST;
  *
  * @ingroup Efl_Text_Markup
  */
-EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
+EAPI EAPI_WEAK void efl_text_markup_set(Eo *obj, const char *markup);
 
 /**
  * @brief Markup property
@@ -46,6 +46,6 @@ EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
  *
  * @ingroup Efl_Text_Markup
  */
-EOAPI const char *efl_text_markup_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_text_markup_get(const Eo *obj);
 
 #endif
