@@ -46,7 +46,7 @@ typedef struct _Efl_Ui_Factory_Item_Created_Event
  */
 #define EFL_UI_FACTORY_INTERFACE efl_ui_factory_interface_get()
 
-EWAPI const Efl_Class *efl_ui_factory_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_factory_interface_get(void) EINA_CONST;
 
 #ifdef EFL_UI_FACTORY_PROTECTED
 /**
@@ -67,7 +67,7 @@ EWAPI const Efl_Class *efl_ui_factory_interface_get(void);
  *
  * @ingroup Efl_Ui_Factory
  */
-EOAPI Eina_Future *efl_ui_factory_create(Eo *obj, Eina_Iterator *models EFL_TRANSFER_OWNERSHIP) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK Eina_Future *efl_ui_factory_create(Eo *obj, Eina_Iterator *models EFL_TRANSFER_OWNERSHIP) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif
 
 /**
@@ -80,9 +80,9 @@ EOAPI Eina_Future *efl_ui_factory_create(Eo *obj, Eina_Iterator *models EFL_TRAN
  *
  * @ingroup Efl_Ui_Factory
  */
-EOAPI void efl_ui_factory_release(Eo *obj, Eina_Iterator *ui_views EFL_TRANSFER_OWNERSHIP);
+EAPI EAPI_WEAK void efl_ui_factory_release(Eo *obj, Eina_Iterator *ui_views EFL_TRANSFER_OWNERSHIP);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CONSTRUCTING;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CONSTRUCTING;
 
 /** Event emitted when an item is under construction (between the
  * @ref efl_constructor and @ref efl_finalize call on the item). Note: If the
@@ -96,7 +96,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CONSTRUCTING
  */
 #define EFL_UI_FACTORY_EVENT_ITEM_CONSTRUCTING (&(_EFL_UI_FACTORY_EVENT_ITEM_CONSTRUCTING))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_BUILDING;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_BUILDING;
 
 /** Event emitted when an item has processed @ref efl_finalize, but before all
  * the factory are done building it. Note: If the @ref Efl_Ui_Factory keeps a
@@ -110,7 +110,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_BUILDING;
  */
 #define EFL_UI_FACTORY_EVENT_ITEM_BUILDING (&(_EFL_UI_FACTORY_EVENT_ITEM_BUILDING))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CREATED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CREATED;
 
 /** Event emitted when an item has been successfully created by the factory and
  * is about to be used by an @ref Efl_Ui_View.
@@ -122,7 +122,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_CREATED;
  */
 #define EFL_UI_FACTORY_EVENT_ITEM_CREATED (&(_EFL_UI_FACTORY_EVENT_ITEM_CREATED))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_RELEASING;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FACTORY_EVENT_ITEM_RELEASING;
 
 /** Event emitted when an item is being released by the @ref Efl_Ui_Factory. It
  * must be assumed that after this call, the object can be recycles to another
