@@ -74,7 +74,7 @@ typedef enum
  */
 #define EFL_UI_LAYOUT_ORIENTABLE_INTERFACE efl_ui_layout_orientable_interface_get()
 
-EWAPI const Efl_Class *efl_ui_layout_orientable_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_layout_orientable_interface_get(void) EINA_CONST;
 
 /**
  * @brief Control the direction of a given widget.
@@ -93,7 +93,7 @@ EWAPI const Efl_Class *efl_ui_layout_orientable_interface_get(void);
  *
  * @ingroup Efl_Ui_Layout_Orientable
  */
-EOAPI void efl_ui_layout_orientation_set(Eo *obj, Efl_Ui_Layout_Orientation dir);
+EAPI EAPI_WEAK void efl_ui_layout_orientation_set(Eo *obj, Efl_Ui_Layout_Orientation dir);
 
 /**
  * @brief Control the direction of a given widget.
@@ -113,6 +113,6 @@ EOAPI void efl_ui_layout_orientation_set(Eo *obj, Efl_Ui_Layout_Orientation dir)
  *
  * @ingroup Efl_Ui_Layout_Orientable
  */
-EOAPI Efl_Ui_Layout_Orientation efl_ui_layout_orientation_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Layout_Orientation efl_ui_layout_orientation_get(const Eo *obj);
 
 #endif
