@@ -15,12 +15,16 @@ typedef Eo Efl_Ui_View;
  *
  * @since 1.23
  *
- * @ingroup Efl
+ * @ingroup Efl_Model_Changed_Event
  */
 typedef struct _Efl_Model_Changed_Event
 {
-  Efl_Model *current; /**< The newly set model. */
-  Efl_Model *previous; /**< The previously set model. */
+  Efl_Model *current; /**< The newly set model.
+                       *
+                       * @since 1.23 */
+  Efl_Model *previous; /**< The previously set model.
+                        *
+                        * @since 1.23 */
 } Efl_Model_Changed_Event;
 
 
@@ -33,7 +37,7 @@ typedef struct _Efl_Model_Changed_Event
  */
 #define EFL_UI_VIEW_INTERFACE efl_ui_view_interface_get()
 
-EWAPI const Efl_Class *efl_ui_view_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_view_interface_get(void) EINA_CONST;
 
 /**
  * @brief Model that is/will be
@@ -45,7 +49,7 @@ EWAPI const Efl_Class *efl_ui_view_interface_get(void);
  *
  * @ingroup Efl_Ui_View
  */
-EOAPI void efl_ui_view_model_set(Eo *obj, Efl_Model *model);
+EAPI EAPI_WEAK void efl_ui_view_model_set(Eo *obj, Efl_Model *model);
 
 /**
  * @brief Model that is/will be
@@ -58,9 +62,9 @@ EOAPI void efl_ui_view_model_set(Eo *obj, Efl_Model *model);
  *
  * @ingroup Efl_Ui_View
  */
-EOAPI Efl_Model *efl_ui_view_model_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Model *efl_ui_view_model_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_VIEW_EVENT_MODEL_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_VIEW_EVENT_MODEL_CHANGED;
 
 /** Event dispatched when a new model is set.
  * @return Efl_Model_Changed_Event
