@@ -38,7 +38,7 @@
  * @note Returning EINA_TRUE is important so we don't stop iterating over the
  * container.
  *
- * And here a more interesting function, it uses an iterator to print the
+ * And here's a more interesting function, it uses an iterator to print the
  * contents of a container. What's interesting about it is that it doesn't care
  * the type of container, it works for anything that can provide an iterator:
  * @until }
@@ -67,7 +67,7 @@
  * also printed, so now we go to the cool stuff and use an iterator to do same
  * stuff to a list:
  * @until eina_iterator_free
- * @note The only significant diference to the block above is in the
+ * @note The only significant difference to the block above is in the
  * function used to create the iterator.
  *
  * And now we free the list and shut eina down:
@@ -87,16 +87,16 @@
  *
  * @brief These functions manage iterators on containers.
  *
- * These functions allow to access elements of a container in a
+ * These functions allow accessing elements of a container in a
  * generic way, without knowing which container is used (a bit like
- * iterators in the C++ STL). Iterators only allows sequential access
- * (that is, from an element to the next one). For random access, see
+ * iterators in the C++ STL). Iterators only allow sequential access
+ * (that is, from one element to the next one). For random access, see
  * @ref Eina_Accessor_Group.
  *
  * Getting an iterator to access elements of a given container is done through
  * the functions of that particular container. There is no function to create
  * a generic iterator as iterators absolutely depend on the container. This
- * means you won't find iterator creation function here, those can be found on
+ * means you won't find an iterator creation function here, those can be found with
  * the documentation of the container type you're using. Though created with
  * container specific functions iterators are always deleted with the same
  * function: eina_iterator_free().
@@ -197,31 +197,31 @@ struct _Eina_Iterator
 
 
 /**
- * @brief Free an iterator.
+ * @brief Frees an iterator.
  *
- * @param iterator The iterator to free.
+ * @param[in,out] iterator The iterator to free.
  *
  * This function frees @p iterator if it is not @c NULL;
  */
-EAPI void      eina_iterator_free(Eina_Iterator *iterator);
+EINA_API void      eina_iterator_free(Eina_Iterator *iterator);
 
 
 /**
- * @brief Return the container of an iterator.
+ * @brief Returns the container of an iterator.
  *
- * @param iterator The iterator.
+ * @param[in] iterator The iterator.
  * @return The container which created the iterator.
  *
  * This function returns the container which created @p iterator. If
  * @p iterator is @c NULL, this function returns @c NULL.
  */
-EAPI void     *eina_iterator_container_get(Eina_Iterator *iterator) EINA_ARG_NONNULL(1) EINA_PURE;
+EINA_API void     *eina_iterator_container_get(Eina_Iterator *iterator) EINA_ARG_NONNULL(1) EINA_PURE;
 
 /**
- * @brief Return the value of the current element and go to the next one.
+ * @brief Returns the value of the current element and go to the next one.
  *
- * @param iterator The iterator.
- * @param data The data of the element.
+ * @param[in,out] iterator The iterator.
+ * @param[out] data The data of the element.
  * @return #EINA_TRUE on success, #EINA_FALSE otherwise.
  *
  * This function returns the value of the current element pointed by
@@ -229,33 +229,33 @@ EAPI void     *eina_iterator_container_get(Eina_Iterator *iterator) EINA_ARG_NON
  * iterator is @c NULL or if a problem occurred, #EINA_FALSE is
  * returned, otherwise #EINA_TRUE is returned.
  */
-EAPI Eina_Bool eina_iterator_next(Eina_Iterator *iterator,
+EINA_API Eina_Bool eina_iterator_next(Eina_Iterator *iterator,
                                   void         **data) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 
 /**
- * @brief Iterate over the container and execute a callback on each element.
+ * @brief Iterates over the container and execute a callback on each element.
  *
- * @param iterator The iterator.
- * @param callback The callback called on each iteration.
- * @param fdata The data passed to the callback.
+ * @param[in,out] iterator The iterator.
+ * @param[in] callback The callback called on each iteration.
+ * @param[in] fdata The data passed to the callback.
  *
  * This function iterates over the elements pointed by @p iterator,
- * beginning from the current element. For Each element, the callback
+ * beginning with the current element. For each element, the callback
  * @p cb is called with the data @p fdata. If @p iterator is @c NULL,
  * the function returns immediately. Also, if @p cb returns #EINA_FALSE,
  * the iteration stops at that point, if @p cb returns #EINA_TRUE
  * the iteration continues.
  */
-EAPI void eina_iterator_foreach(Eina_Iterator *iterator,
+EINA_API void eina_iterator_foreach(Eina_Iterator *iterator,
                                 Eina_Each_Cb   callback,
                                 const void    *fdata) EINA_ARG_NONNULL(2);
 
 
 /**
- * @brief Lock the container of the iterator.
+ * @brief Locks the container of the iterator.
  *
- * @param iterator The iterator.
+ * @param[in,out] iterator The iterator.
  * @return #EINA_TRUE on success, #EINA_FALSE otherwise.
  *
  * If the container of the @p iterator permits it, it will be locked. When a
@@ -266,12 +266,12 @@ EAPI void eina_iterator_foreach(Eina_Iterator *iterator,
  *
  * @warning None of the existing eina data structures are lockable.
  */
-EAPI Eina_Bool eina_iterator_lock(Eina_Iterator *iterator) EINA_ARG_NONNULL(1);
+EINA_API Eina_Bool eina_iterator_lock(Eina_Iterator *iterator) EINA_ARG_NONNULL(1);
 
 /**
- * @brief Unlock the container of the iterator.
+ * @brief Unlocks the container of the iterator.
  *
- * @param iterator The iterator.
+ * @param[in,out] iterator The iterator.
  * @return #EINA_TRUE on success, #EINA_FALSE otherwise.
  *
  * If the container of the @p iterator permits it and was previously
@@ -282,30 +282,130 @@ EAPI Eina_Bool eina_iterator_lock(Eina_Iterator *iterator) EINA_ARG_NONNULL(1);
  *
  * @warning None of the existing eina data structures are lockable.
  */
-EAPI Eina_Bool eina_iterator_unlock(Eina_Iterator *iterator) EINA_ARG_NONNULL(1);
+EINA_API Eina_Bool eina_iterator_unlock(Eina_Iterator *iterator) EINA_ARG_NONNULL(1);
 
 /**
  * @brief Creates an Eina_Iterator that iterates through a
  * NUL-terminated C array.
  *
- * @param array The NUL-terminated array
+ * @param[in] array The NUL-terminated array
+ * @return The iterator that will walk over the array.
  *
  * You can create it like this:
  * int array[] = {1, 2, 3, 4};
  * int* array2[] = {&array[0], &array[1], &array[2], &array[3], NULL};
  *
- * Eina_Iterator* iterator = eina_carray_iterator_new((void**)array);
+ * Eina_Iterator* iterator = eina_carray_iterator_new((void**)array2);
  *
  * @since 1.18
  */
-EAPI Eina_Iterator* eina_carray_iterator_new(void** array) EINA_ARG_NONNULL(1) EINA_WARN_UNUSED_RESULT;
+EINA_API Eina_Iterator *eina_carray_iterator_new(void** array) EINA_ARG_NONNULL(1) EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Creates an Eina_Iterator that iterates through a
+ * C array of specified size.
+ *
+ * @param[in] array The array
+ * @return The iterator that will walk over the array.
+ *
+ * You can create it like this:
+ * int array[] = {1, 2, 3, 4};
+ *
+ * Eina_Iterator* iterator = eina_carray_length_iterator_new((void**)array, sizeof (array[0]), (EINA_C_ARRAY_LENGTH(array));
+ *
+ * @since 1.22
+ */
+EINA_API Eina_Iterator *eina_carray_length_iterator_new(void** array, unsigned int step, unsigned int length) EINA_ARG_NONNULL(1) EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @def EINA_C_ARRAY_ITERATOR_NEW
+ * @brief Creates an Eina_Iterator that iterates through a
+ * NUL-terminated C array.
+ *
+ * @param[in] Array The NUL-terminated array
+ * @return The iterator that will walk over the array.
+ *
+ * You can create it like this:
+ * int array[] = {1, 2, 3, 4};
+ *
+ * Eina_Iterator* iterator = EINA_C_ARRAY_ITERATOR_NEW(array);
+ *
+ * @since 1.22
+ */
+#define EINA_C_ARRAY_ITERATOR_NEW(Array) eina_carray_length_iterator_new((void**) Array, sizeof (Array[0]), EINA_C_ARRAY_LENGTH(Array))
+
+/**
+ * @brief Creates a new iterator which which iterates through all elements with are accepted by the filter callback
+ *
+ * @param[in] original the iterator the use as original set
+ * @param[in] filter if the callback returns true the element from the original set is taken into the the new set.
+ * @param[in] free_cb when the iterator is gone this callback will be called with data as argument
+ * @param[in] data the data which is passed to the filter callback
+ *
+ * The iterator is filtered while it is being iterated.
+ * The original iterator you pass in here is is then owned and will be freed once the the new iterator is freed.
+ *
+ * @since 1.19
+ */
+EINA_API Eina_Iterator* eina_iterator_filter_new(Eina_Iterator *original, Eina_Each_Cb filter, Eina_Free_Cb free_cb, void *data) EINA_ARG_NONNULL(1) EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Creates an Eina_Iterator that iterates through a series
+ * of Eina_Iterator.
+ *
+ * @param[in] it The first Eina_Iterator to iterate over
+ * @return The iterator that will walk all the other iterator
+ *
+ * Eina_Iterator* iterator = eina_multi_iterator_new(it1, it2, it3, NULL);
+ *
+ * @note The returned array will destroy iterator given to it once they are not
+ * necessary anymore. Taking ownership of those iterator.
+ *
+ * @since 1.22
+ */
+EINA_API Eina_Iterator *eina_multi_iterator_internal_new(Eina_Iterator *it, ...) EINA_ARG_NONNULL(1) EINA_WARN_UNUSED_RESULT;
+
+
+/**
+ * @brief Calls the process method on each node of iterator, producing new "processed"
+ * nodes and returning a new iterator which contains them.
+ *
+ * @param[in] iterator Iterator containing the nodes to process.
+ * @param[in] process Method to call on each node.
+ * @param[in] free_cb Method called when all nodes have been processed. It receives "data" as a parameter.
+ * @param[in] fdata Additional data passed to the process method.
+ *
+ * Processes every node in the input iterator and returns a new iterator containing
+ * the processed nodes. This is akin to a Map function:
+ * https://en.wikipedia.org/wiki/Map_(higher-order_function)
+ *
+ * @since 1.24
+ */
+EINA_API Eina_Iterator* eina_iterator_processed_new(Eina_Iterator *iterator, Eina_Process_Cb process, Eina_Free_Cb free_cb, void *fdata) EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @def eina_multi_iterator_new
+ * @brief Creates an Eina_Iterator that iterates through a series
+ * of Eina_Iterator.
+ *
+ * @param[in] It The first Eina_Iterator to iterate over
+ * @return The iterator that will walk all the other iterator
+ *
+ * Eina_Iterator* iterator = eina_multi_iterator_new(it1, it2, it3);
+ *
+ * @note The returned array will destroy iterator given to it once they are not
+ * necessary anymore. Taking ownership of those iterator.
+ *
+ * @since 1.22
+ */
+#define eina_multi_iterator_new(It, ...) eina_multi_iterator_internal_new(It, ##__VA_ARGS__, NULL)
 
 /**
  * @def EINA_ITERATOR_FOREACH
- * @brief Macro to iterate over all elements easily.
+ * @brief Definition for the macro to iterate over all elements easily.
  *
- * @param itr The iterator to use.
- * @param data Where to store * data, must be a pointer support getting
+ * @param[in,out] itr The iterator to use.
+ * @param[out] data Where to store * data, must be a pointer support getting
  *        its address since * eina_iterator_next() requires a pointer
  *        to pointer!
  *
@@ -331,7 +431,7 @@ EAPI Eina_Iterator* eina_carray_iterator_new(void** array) EINA_ARG_NONNULL(1) E
  * eina_list_free(list);
  * @endcode
  *
- * @note this example is not optimal algorithm to release a list since
+ * @note This example is not optimal algorithm to release a list since
  *    it will walk the list twice, but it serves as an example. For
  *    optimized version use EINA_LIST_FREE()
  *
@@ -341,7 +441,7 @@ EAPI Eina_Iterator* eina_carray_iterator_new(void** array) EINA_ARG_NONNULL(1) E
  * @warning unless explicitly stated in functions returning iterators,
  *    do not modify the iterated object while you walk it, in this
  *    example using lists, do not remove list nodes or you might
- *    crash!  This is not a limitiation of iterators themselves,
+ *    crash!  This is not a limitation of iterators themselves,
  *    rather in the iterators implementations to keep them as simple
  *    and fast as possible.
  */
