@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Navigation_Bar_Part_Back_Button;
  */
 #define EFL_UI_NAVIGATION_BAR_PART_BACK_BUTTON_CLASS efl_ui_navigation_bar_part_back_button_class_get()
 
-EWAPI const Efl_Class *efl_ui_navigation_bar_part_back_button_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_navigation_bar_part_back_button_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
