@@ -25,7 +25,7 @@ typedef Eo Efl_Ui_Position_Manager_Grid;
  */
 #define EFL_UI_POSITION_MANAGER_GRID_CLASS efl_ui_position_manager_grid_class_get()
 
-EWAPI const Efl_Class *efl_ui_position_manager_grid_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_position_manager_grid_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
