@@ -28,6 +28,6 @@ typedef Eo Efl_Canvas_Parallel_Group_Animation;
  */
 #define EFL_CANVAS_PARALLEL_GROUP_ANIMATION_CLASS efl_canvas_parallel_group_animation_class_get()
 
-EWAPI const Efl_Class *efl_canvas_parallel_group_animation_class_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_parallel_group_animation_class_get(void) EINA_CONST;
 
 #endif
