@@ -20,7 +20,7 @@ typedef Eo Efl_Canvas_Vg_Container;
  */
 #define EFL_CANVAS_VG_CONTAINER_CLASS efl_canvas_vg_container_class_get()
 
-EWAPI const Efl_Class *efl_canvas_vg_container_class_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_vg_container_class_get(void) EINA_CONST;
 
 /**
  * @brief Get child of container
@@ -32,7 +32,7 @@ EWAPI const Efl_Class *efl_canvas_vg_container_class_get(void);
  *
  * @ingroup Efl_Canvas_Vg_Container
  */
-EOAPI Efl_Canvas_Vg_Node *efl_canvas_vg_container_child_get(Eo *obj, const char *name);
+EVAS_API EVAS_API_WEAK Efl_Canvas_Vg_Node *efl_canvas_vg_container_child_get(Eo *obj, const char *name);
 
 /**
  * @brief Get all children of container
@@ -43,7 +43,18 @@ EOAPI Efl_Canvas_Vg_Node *efl_canvas_vg_container_child_get(Eo *obj, const char
  *
  * @ingroup Efl_Canvas_Vg_Container
  */
-EOAPI Eina_Iterator *efl_canvas_vg_container_children_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EVAS_API EVAS_API_WEAK Eina_Iterator *efl_canvas_vg_container_children_get(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Get all children of container
+ *
+ * @param[in] obj The object.
+ *
+ * @return List to children
+ *
+ * @ingroup Efl_Canvas_Vg_Container
+ */
+EVAS_API EVAS_API_WEAK const Eina_List *efl_canvas_vg_container_children_direct_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
