@@ -21,7 +21,7 @@ typedef Eo Efl_Input_Hold;
  */
 #define EFL_INPUT_HOLD_CLASS efl_input_hold_class_get()
 
-EWAPI const Efl_Class *efl_input_hold_class_get(void) EINA_CONST;
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_input_hold_class_get(void) EINA_CONST;
 
 /**
  * @brief Property to show if inputs are now on hold.
@@ -33,7 +33,7 @@ EWAPI const Efl_Class *efl_input_hold_class_get(void) EINA_CONST;
  *
  * @ingroup Efl_Input_Hold
  */
-EOAPI void efl_input_hold_set(Eo *obj, Eina_Bool val);
+EVAS_API EVAS_API_WEAK void efl_input_hold_set(Eo *obj, Eina_Bool val);
 
 /**
  * @brief Property to show if inputs are now on hold.
@@ -46,6 +46,6 @@ EOAPI void efl_input_hold_set(Eo *obj, Eina_Bool val);
  *
  * @ingroup Efl_Input_Hold
  */
-EOAPI Eina_Bool efl_input_hold_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_input_hold_get(const Eo *obj);
 
 #endif
