@@ -27,7 +27,7 @@ typedef Eo Efl_Canvas_Gesture_Double_Tap;
  */
 #define EFL_CANVAS_GESTURE_DOUBLE_TAP_CLASS efl_canvas_gesture_double_tap_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_double_tap_class_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_gesture_double_tap_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
